@@ -37,7 +37,6 @@
 #'   \item{no-check-bbs}{ disable BBS-specific checks (for non-BioC packages).
 #'     Valid DESCRIPTION}
 #'   \item{no-check-description}{ disable DESCRIPTION file checks}
-#'   \item{no-check-namespace}{ disable namespace checks}
 #'   \item{no-check-vignettes}{ disable vignette checks}
 #'   \item{no-check-library-calls}{ disable check usage of functions that
 #'     install or update packages}
@@ -60,7 +59,7 @@
 #'   \item{quit-with-status}{ enable exit code option when performing check}
 #' }
 #'
-#' @param package The path to an R package directory or tarball (`.tar.gz`). 
+#' @param package The path to an R package directory or tarball (`.tar.gz`).
 #'   The `BiocCheck` function is intended to be run from the package
 #'   directory; therefore, the current working directory (given by `getwd()`)
 #'   is the default.
@@ -114,9 +113,6 @@ BiocCheck <- function(
     ...
 ) {
     if (callr) {
-        if (!requireNamespace("callr", quietly = TRUE))
-            stop("Install the 'callr' package to run 'BiocCheck()'",
-                 " in a separate R session")
         callr::r(
             function(...) { BiocCheck:::BiocCheckRun(...) },
             args = list(
@@ -165,6 +161,7 @@ BiocCheckRun <-
     checkDir <- .getBiocCheckDir(package_name, checkDir)
     isBBS <- Sys.getenv("IS_BIOC_BUILD_MACHINE")
     onBBS <- nzchar(isBBS) && identical(tolower(isBBS), "true")
+    hasAdmin <- nzchar(Sys.getenv("BIOC_DEVEL_PASSWORD"))
 
     .BiocCheck$metadata <- list(
         BiocCheckVersion = bioccheckver,
@@ -177,7 +174,8 @@ BiocCheckRun <-
     .BiocCheck$show_meta()
 
     handleMessage("* Installing package...", indent = 0, exdent = 0)
-    ## checks
+
+    # BiocCheck checks --------------------------------------------------------
     if (is.null(dots[["no-check-deprecated"]])){
         handleCheck("Checking for deprecated package usage...")
         checkDeprecatedPackages(package_dir)
@@ -218,13 +216,14 @@ BiocCheckRun <-
         if (source_tarball){
             checkPackageSize(package, package_dir, size=5)
         } else {
-            handleMessage("Skipped... only checked on source tarball", indent=6)
+            handleMessage("Skipped... only checked on source tarball", indent=4)
         }
     }
 
     if (is.null(dots[["no-check-file-size"]])){
         handleCheck("Checking individual file sizes...")
         checkIndivFileSizes(package_dir)
+        checkDataFileSizes(package_dir)
     }
 
     if (is.null(dots[["no-check-bioc-views"]]))
@@ -248,25 +247,17 @@ BiocCheckRun <-
         checkDESCRIPTIONFile(package_dir)
     }
 
-    if (is.null(dots[["no-check-namespace"]])){
-        handleCheck("Checking DESCRIPTION/NAMESPACE consistency...")
-        checkDescriptionNamespaceConsistency(package_name, libloc)
-
-        if (suppressMessages(suppressWarnings(requireNamespace("codetoolsBioC",
-                                                               quietly=TRUE))))
-            {
-                handleCheck("Checking for namespace import suggestions...")
-                .BiocCheck$writeNSsuggests(onBBS)
-                # checkImportSuggestions(package_name)
-            }
-    }
-
     handleCheck("Checking .Rbuildignore...")
     checkRbuildignore(package_dir)
 
     handleCheck("Checking for stray BiocCheck output folders...")
     checkBiocCheckOutputFolder(package_dir, package_name)
 
+    if (!isTar) {
+        handleCheck("Checking for inst/doc folders...")
+        checkInstDocFolder(package_dir, package_name)
+    }
+
     if (is.null(dots[["no-check-vignettes"]])) {
         handleCheck("Checking vignette directory...")
         checkVignetteDir(package_dir, checkingDir)
@@ -347,7 +338,7 @@ BiocCheckRun <-
 
     if (is.null(dots[["no-check-bioc-help"]])) {
         handleCheck("Checking for bioc-devel mailing list subscription...")
-        if (onBBS) {
+        if (hasAdmin) {
             checkForBiocDevelSubscription(package_dir)
         } else {
             handleNote(
