@@ -227,7 +227,7 @@ checkDataFileSizes <- function(pkgdir) {
     entries <- Filter(nchar,
         grep("^#", trimws(text), value = TRUE, invert = TRUE)
     )
-    grepl("\\^*tests\\$*", entries)
+    grepl("^\\^?(long)?tests[\\$\\/]?$", entries)
 }
 
 checkRbuildignore <- function(pkgdir) {
@@ -237,7 +237,7 @@ checkRbuildignore <- function(pkgdir) {
         testIgnore <- .testRbuildignore(rbuild)
         if (any(testIgnore))
             handleError(
-                ".Rbuildignore file includes the 'tests' folder."
+                ".Rbuildignore includes 'tests' or 'longtests' folder."
             )
     }
 }
@@ -260,42 +260,46 @@ checkInstDocFolder <- function(pkgdir, pkg_name) {
         )
 }
 
+.readBiocViews <- function(pkgdir) {
+    desc <- file.path(pkgdir, "DESCRIPTION")
+    dcf <- read.dcf(desc)
+    .parseBiocViews(dcf)
+}
+
+.parseBiocViews <- function(dcf) {
+    if ("biocViews" %in% colnames(dcf))
+        strsplit(dcf[, "biocViews"], "\\s*,\\s*")[[1]]
+    else
+        ""
+}
+
 checkBiocViews <- function(pkgdir)
 {
-    dirty <- FALSE
-    dcf <- read.dcf(file.path(pkgdir, "DESCRIPTION"))
+    invalid <- FALSE
     handleCheck("Checking that biocViews are present...")
-    if (!"biocViews" %in% colnames(dcf))
-    {
+    views <- .readBiocViews(pkgdir)
+    if (identical(length(views), 1L) && !nzchar(views)) {
         handleError("No biocViews terms found.")
         return(TRUE)
     }
-    biocViews <- dcf[, "biocViews"]
-    views <- strsplit(gsub("\\s*,\\s*", ",", biocViews), ",")[[1]]
-    # views <- gsub("\\s", "", views)
-    dataenv <- new.env(parent = emptyenv())
-    data("biocViewsVocab", package="biocViews", envir=dataenv)
-    biocViewsVocab <- dataenv[["biocViewsVocab"]]
+
+    biocViewsVocab <- .load_data("biocViewsVocab", "biocViews")
+
     handleCheck("Checking package type based on biocViews...")
     type <- guessPackageType(views)
     handleMessage(type)
     handleCheck("Checking for non-trivial biocViews...")
     toplevel <- c("Software", "AnnotationData", "ExperimentData", "Workflow")
-    if (!length(views)) {
-        handleError("No biocViews terms found.")
+    if (all(views %in% toplevel)) {
+        handleError(
+            "Add biocViews other than ",
+            paste(unique(views), collapse=", ")
+        )
         return(TRUE)
-    } else {
-        if (all(views %in% toplevel)) {
-            handleError(
-                "Add biocViews other than ",
-                paste(unique(views), collapse=", ")
-            )
-            return(TRUE)
-        }
     }
 
-    parents <-
-        unlist(lapply(views, getParent, biocViewsVocab), use.names=FALSE)
+    parents <- vapply(views, getParent, character(1L), biocViewsVocab)
+    parents <- Filter(nzchar, parents)
 
     handleCheck("Checking that biocViews come from the same category...")
     if (length(unique(parents)) > 1)
@@ -338,7 +342,7 @@ checkBiocViews <- function(pkgdir)
         handleWarning(
             "Invalid BiocViews term(s):", messages = unlist(suggestedViews)
         )
-        dirty <- TRUE
+        invalid <- TRUE
     }
 
     if (packageVersion("biocViews") < package_version("1.33.9")) {
@@ -348,23 +352,18 @@ checkBiocViews <- function(pkgdir)
     }
 
     handleCheck("Checking for recommended biocViews...")
-    rec <- tryCatch(suppressMessages(suppressWarnings({
-        recommendBiocViews(pkgdir, branch)
-    })), error=function(e) {
-        NULL
-    })
+    recommended <- try({
+        recommendBiocViews(pkgdir, branch)[["recommended"]]
+    }, silent = TRUE)
 
-    if (!is.null(rec))
+    if (!inherits(recommended, "try-error") && nzchar(recommended))
     {
-        if (length(rec$recommended) == 1 && !nzchar(rec$recommended)) {
-        } else {
-            handleNote(
-                "Consider adding these automatically suggested biocViews: ",
-                rec$recommended)
-            dirty <- TRUE
-        }
+        handleNote(
+            "Consider adding these automatically suggested biocViews: ",
+            recommended)
+        invalid <- TRUE
     }
-    return(dirty)
+    return(invalid)
 }
 
 .checkDescription <- function(desc) {
@@ -375,9 +374,9 @@ checkBiocViews <- function(pkgdir)
         desc_sentences <- length(
             strsplit(desc_field, split = "[.!?][[:space:]]+")[[1L]]
         )
-        msg <- "The Description field in the DESCRIPTION is made up by less
-            than 3 sentences. Please consider expanding this field, and
-            structure it as a full paragraph"
+        msg <- "The Description field in the DESCRIPTION is made up of less
+            than 3 sentences. Provide a more detailed description of the
+            package."
 
         # values chosen sensibly in a data-driven manner
         if (nchar(desc_field) < 50 || desc_words < 20)
@@ -435,7 +434,7 @@ checkBBScompatibility <- function(pkgdir, source_tarball)
         )
         return()
     }
-    handleCheck("Checking for Version field...")
+    handleCheck("Checking for Version: field...")
     if (!"Version" %in% colnames(dcf))
     {
         handleError("No 'Version:' field in DESCRIPTION.")
@@ -462,7 +461,7 @@ checkBBScompatibility <- function(pkgdir, source_tarball)
         pp <- parse(text=dcf[,"Authors@R"], keep.source=TRUE)
         tryCatch(people <- eval(pp, env),
             error=function(e) {
-                handleError("AuthorsR@ field must be valid R code.")
+                handleError("Authors@R field must be valid R code.")
             })
         if (!exists("people")) return()
         if (!"person" %in% class(people))
@@ -534,52 +533,6 @@ checkBBScompatibility <- function(pkgdir, source_tarball)
     }
 }
 
-.parsePackageImportsFromNamespace <- function(pkg, libloc) {
-    importFields <- c("imports", "importClasses", "importMethods")
-    imps <- parseNamespaceFile(pkg, libloc)[importFields]
-    for (i in names(imps))
-        imps[[i]] <- vapply(imps[[i]], `[[`, character(1L), 1L)
-    unique(unlist(imps))
-}
-
-checkDescriptionNamespaceConsistency <- function(pkgname, lib.loc)
-{
-    pkg_desc <- packageDescription(pkgname, lib.loc = lib.loc)
-    dImports <- cleanupDependency(pkg_desc$Imports)
-    deps <- cleanupDependency(pkg_desc$Depends)
-    nImports <- .parsePackageImportsFromNamespace(pkgname, lib.loc)
-
-    if(!(all(dImports %in% nImports)))
-    {
-        badones <- dImports[!dImports %in% nImports]
-        tryCatch({
-            ## FIXME: not 100% confident that the following always succeeds
-            pkg_ns <- loadNamespace(pkgname, lib.loc = lib.loc)
-            dcolon <- .checkEnv(pkg_ns, .colonWalker())$done()
-            unloadNamespace(pkg_ns)
-            badones <- setdiff(badones, dcolon)
-        }, error=function(...) NULL)
-        if (length(badones))
-            handleWarning(
-                "Import ", paste(badones, collapse=", "), " in NAMESPACE ",
-                "as well as DESCRIPTION.")
-    }
-    if (!all (nImports %in% dImports))
-    {
-        badones <- nImports[!nImports %in% dImports]
-        if (!is.null(deps))
-        {
-            badones <- badones[!badones %in% deps]
-        }
-        if (length(badones))
-        {
-            handleWarning(
-                "Import ", paste(unique(badones), collapse=", "), " in ",
-                "DESCRIPTION as well as NAMESPACE.")
-        }
-    }
-}
-
 checkVignetteDir <- function(pkgdir, checkingDir)
 {
     vigdir <- file.path(pkgdir, "vignettes")
@@ -609,6 +562,8 @@ checkVignetteDir <- function(pkgdir, checkingDir)
 
     checkVigMetadata(vigdircontents)
 
+    checkVigTypeRNW(vigdircontents)
+
     checkVigEngine(builder, vigdircontents)
 
     checkVigSuggests(builder, vigdircontents, pkgdir)
@@ -617,6 +572,8 @@ checkVignetteDir <- function(pkgdir, checkingDir)
 
     checkVigChunkEval(vigdircontents)
 
+    checkDupChunkLabels(vigdircontents)
+
     checkVigBiocInst(pkgdir)
 
     checkVigInstalls(pkgdir)
@@ -690,6 +647,18 @@ checkVigBuilder <- function(builder, vigdircontents)
     }
 }
 
+checkVigTypeRNW <- function(vigdircontents) {
+    vigExt <- tolower(tools::file_ext(vigdircontents))
+    isRNW <- vigExt == "rnw"
+    vigNames <- basename(vigdircontents[isRNW])
+    if (length(vigNames))
+        handleWarning(
+            "Use RMarkdown instead of Sweave 'Rnw' vignettes.",
+            help_text = "Rnw vignette(s) found:",
+            messages = vigNames
+        )
+}
+
 checkVigMetadata <- function(vigdircontents)
 {
     badVig <- character(0)
@@ -884,6 +853,32 @@ checkVigEvalAllFalse <- function(pkgdir){
     }
 }
 
+checkDupChunkLabels <- function(vigfiles) {
+    viglist <- structure(
+        vector("logical", length(vigfiles)),
+        .Names = vigfiles
+    )
+    for (vfile in vigfiles) {
+        tempR <- tempfile(fileext=".R")
+        tryCatch({
+            quiet_knitr_purl(input = vfile, output = tempR, quiet = TRUE)
+        }, error = function(e) {
+            viglist[[vfile]] <<- grepl(
+                "Duplicate chunk label", conditionMessage(e), fixed = TRUE
+            )
+            if (viglist[[vfile]])
+                invisible(NULL)
+            else
+                stop(e)
+        })
+    }
+    if (any(viglist))
+        handleErrorFiles(
+            " Vignette(s) found with duplicate chunk labels",
+            messages = basename(vigfiles[viglist])
+        )
+}
+
 .OLD_INSTALL_CALLS <-
     c("BiocInstaller", "biocLite", "useDevel", "biocinstallRepos")
 
@@ -937,6 +932,31 @@ quiet_knitr_purl <- function(...)
     )
 }
 
+purl_or_tangle <- function(input, output, quiet, ...) {
+    vigEng <- getVigEngine(input)
+    vigExt <- tolower(tools::file_ext(input))
+    if (!identical(vigExt, "rnw") || identical(vigEng, "knitr"))
+        quiet_knitr_purl(input = input, output = output, quiet = quiet, ...)
+    else
+        utils::Stangle(file = input, output = output, quiet = quiet)
+}
+
+try_purl_or_tangle <- function(input, output, quiet, ...) {
+    tryCatch({
+        purl_or_tangle(input = input, output = output, quiet = quiet, ...)
+    }, error = function(e) {
+        hasDups <- grepl(
+            "Duplicate chunk label", conditionMessage(e), fixed = TRUE
+        )
+        if (hasDups) {
+            file.create(output)
+            invisible(NULL)
+        } else {
+            stop(e)
+        }
+    })
+}
+
 checkVigClassUsage <- function(pkgdir) {
     vigdir <- file.path(pkgdir, "vignettes", "")
     vigfiles <- getVigSources(vigdir)
@@ -945,7 +965,7 @@ checkVigClassUsage <- function(pkgdir) {
     )
     for (vfile in vigfiles) {
         tempR <- tempfile(fileext=".R")
-        quiet_knitr_purl(input = vfile, output = tempR, quiet = TRUE)
+        try_purl_or_tangle(input = vfile, output = tempR, quiet = TRUE)
         tokens <- getClassNEEQLookup(tempR)
         viglist[[basename(vfile)]] <- sprintf(
             "%s (code line %d, column %d)",
@@ -1040,7 +1060,7 @@ findSymbolsInVignettes <-
     viglist <- list()
     for (vfile in vigfiles) {
         tempR <- tempfile(fileext=".R")
-        quiet_knitr_purl(input = vfile, output = tempR, quiet = TRUE)
+        try_purl_or_tangle(input = vfile, output = tempR, quiet = TRUE)
         tokens <- FUN(parseFile(tempR, pkgdir), tokenTypes, Symbols)
         viglist[[.getDirFiles(vfile)]] <- sprintf(
             "%s (code line %d, column %d)",
@@ -1207,6 +1227,18 @@ checkCodingPractice <- function(pkgdir, parsedCode, package_name)
         )
     }
 
+    # .Deprecated / .Defunct usage should be updated after every release
+    msg_depr <- findSymbolsInRFiles(
+        pkgdir, c(".Deprecated", ".Defunct"), "SYMBOL_FUNCTION_CALL"
+    )
+    if (length(msg_depr)) {
+        handleWarning(
+            ".Deprecated / .Defunct usage (found ",
+            length(msg_depr), " times)",
+            messages = msg_depr
+        )
+    }
+
     handleCheck("Checking parsed R code in R directory, examples, vignettes...")
 
     # direct slot access
@@ -1714,37 +1746,53 @@ checkForPromptComments <- function(pkgdir)
     )
 }
 
-.formatsInParsedRd <- function(rds, tags) {
-    formats <- .tagsExtract(rds, tags, "\\format")
+.formatsInParsedRd <- function(rd, tags) {
+    formats <- .tagsExtract(rd, tags, "\\format")
     value <- paste(formats, collapse = "")
     nzchar(trimws(value)) && length(formats)
 }
 
-.isValidRdSkip <- function(rds, tags) {
-    dt <- docType(rds, tags)
-    identical(dt, "package") ||
-        (identical(dt, "data") && .formatsInParsedRd(rds, tags))
+.skipRdCheck <- function(rd, tags) TRUE
+
+.whichRdCheck <- function(docType) {
+    switch(
+        docType,
+        package =,
+        class = .skipRdCheck,
+        data = .formatsInParsedRd,
+        fun =,
+        .valueInParsedRd
+    )
 }
 
 checkForValueSection <- function(pkgdir)
 {
     all_rds <- .read_all_rds(pkgdir)
     all_tags <- lapply(all_rds, tools:::RdTags)
+    docTypes <- mapply(docType, rd = all_rds, tags = all_tags, SIMPLIFY = FALSE)
+    docTypes[!lengths(docTypes)] <- "fun"
+    funs <- lapply(docTypes, .whichRdCheck)
+    isData <- unlist(docTypes) == "data"
     ok <- mapply(
-        function(rds, tags) {
-            if (.isValidRdSkip(rds, tags))
-                TRUE
-            else
-                .valueInParsedRd(rds, tags)
+        function(afun, rds, atags) {
+            afun(rds, atags)
         },
-        rds = all_rds,
-        tags = all_tags,
+        afun = funs, rds = all_rds, atags = all_tags,
         SIMPLIFY = TRUE
     )
-    if (!all(ok)) {
-        not_oks <- names(ok[!ok])
+    dataOK <- ok[isData]
+    elseOK <- ok[!isData]
+    if (!all(dataOK)) {
+        not_oks <- names(ok[isData][!dataOK])
         handleWarningFiles(
-            "Empty or missing \\value sections found in man pages.",
+            "Empty or missing \\format sections found in data man page(s).",
+            messages = not_oks
+        )
+    }
+    if (!all(elseOK)) {
+        not_oks <- names(ok[!isData][!elseOK])
+        handleWarningFiles(
+            "Empty or missing \\value sections found in man page(s).",
             messages = not_oks
         )
     }
@@ -1978,6 +2026,11 @@ checkSkipOnBioc <- function(pkgdir)
     lines
 }
 
+.roxygen_in_desc <- function(pkgdir) {
+    dcf <- read.dcf(file.path(pkgdir, "DESCRIPTION"))
+    "RoxygenNote" %in% colnames(dcf)
+}
+
 checkFormatting <- function(pkgdir, nlines=6)
 {
     pkgname <- basename(pkgdir)
@@ -1985,8 +2038,9 @@ checkFormatting <- function(pkgdir, nlines=6)
         dir(file.path(pkgdir, "R"), pattern="\\.R$", ignore.case=TRUE,
             full.names=TRUE),
         file.path(pkgdir, "NAMESPACE"),
-        dir(file.path(pkgdir, "man"), pattern="\\.Rd$", ignore.case=TRUE,
-            full.names=TRUE),
+        if (!.roxygen_in_desc(pkgdir))
+            dir(file.path(pkgdir, "man"), pattern="\\.Rd$", ignore.case=TRUE,
+                full.names=TRUE),
         dir(file.path(pkgdir, "vignettes"), full.names=TRUE,
             pattern="\\.Rnw$|\\.Rmd$|\\.Rrst$|\\.Rhtml$|\\.Rtex$",
             ignore.case=TRUE)
@@ -2131,10 +2185,14 @@ checkIsPackageNameAlreadyInUse <- function(
 checkForBiocDevelSubscription <- function(pkgdir)
 {
     email <- getMaintainerEmail(pkgdir)
-    ## TODO: Return an error when no email found.
-    if (!exists("email"))
+    if (is.null(email)) {
+        handleError(
+            "Unable to determine maintainer email from DESCRIPTION file.",
+            nframe = 3L
+        )
         return()
-    if (tolower(email) == "maintainer@bioconductor.org")
+    }
+    if (identical(tolower(email), "maintainer@bioconductor.org"))
     {
         handleMessage("Maintainer email is ok.")
         return()
@@ -2148,12 +2206,12 @@ checkForBiocDevelSubscription <- function(pkgdir)
     }, silent = TRUE)
     if (inherits(response, "try-error")) {
         handleMessage(
-            "Unable to connect to the Bioc-devel mailing list",
+            "Unable to connect to the Bioc-devel mailing list:",
             "\n  ", conditionMessage(attr(response, "condition")))
         return()
     } else if (resp_status(response) >= 300) {
         handleMessage(
-            "Unable to connect to the Bioc-devel mailing list",
+            "Unable to connect to the Bioc-devel mailing list:",
             "\n  status code ", resp_status(response))
         return()
     }
@@ -2181,7 +2239,7 @@ checkForBiocDevelSubscription <- function(pkgdir)
 checkForSupportSiteRegistration <- function(package_dir)
 {
     email <- getMaintainerEmail(package_dir)
-    if (tolower(email) == "maintainer@bioconductor.org")
+    if (identical(tolower(email), "maintainer@bioconductor.org"))
     {
         handleMessage("Maintainer email is ok.")
         return()
@@ -2294,10 +2352,12 @@ checkBadFiles <- function(package_dir){
     }
 }
 
+.LICENSE_DB_LOCATION <- "$R_HOME/share/licenses/license.db"
+
 .checkLicenseForRestrictiveUse <- function(license) {
     handleCheck("Checking License: for restrictive use...")
 
-    if (length(license) != 1L || is.na(license)) {
+    if (!identical(length(license), 1L) || is.na(license)) {
         handleNote("malformed 'License:' field '", license, "'")
         return(invisible())
     }
@@ -2311,32 +2371,30 @@ checkBadFiles <- function(package_dir){
         return(invisible())
     }
     licenses <- read.dcf(ldb_file)
-    sss <- licenses[, "SSS"]
-    abbrev <- licenses[, "Abbrev"]
-    abbrev[!is.na(sss)] <- sss[!is.na(sss)]
-    restrict <- licenses[, "Restricts_use"]
-    idx <- (restrict == "yes") & !is.na(restrict) & !is.na(abbrev)
-
-    ## PCAN/DESCRIPTION:License: CC BY-NC-ND 4.0
-    ## QUBIC/DESCRIPTION:License: CC BY-NC-ND 4.0 + file LICENSE
-    test0 <- any(vapply(abbrev[idx], grepl, logical(1), license, fixed = TRUE))
-    test1 <-
-        !any(vapply(
-             abbrev[!is.na(abbrev)], grepl, logical(1), license, fixed = TRUE
-         ))
-    if (test0) {
+    result <- tools:::analyze_licenses(license, licenses)
+    test <- result[["restricts_use"]]
+    if (isTRUE(test))
         handleError("License '", license, "' restricts use")
-    } else if (test1) {
+    else if (is.na(test) || !result[, "is_verified"]) {
         handleNote(
-            "License '", license, "' unknown; licenses cannot restrict use"
+            "License '", license, "' unknown; refer to ", .LICENSE_DB_LOCATION
+        )
+        handleMessage(
+            "and https://choosealicense.com/appendix/ for more info.",
+            indent = 6L
         )
     }
 }
 
 .checkDESCfields <- function(dcf) {
-    handleCheck("Checking for recommeded fields in DESCRIPTION...")
+    handleCheck("Checking for recommended DESCRIPTION fields...")
 
     fields <- c("URL", "BugReports")
+    if ("Date" %in% colnames(dcf)) {
+        date <- dcf[, "Date"]
+        if (!grepl("^\\d{4}-\\d{2}-\\d{2}$", date))
+            handleNote("'Date:' field format is not 'YYYY-MM-DD': ", date)
+    }
     present <- fields %in% colnames(dcf)
     res <- fields[!present]
     if (length(res)) {
@@ -2345,6 +2403,38 @@ checkBadFiles <- function(package_dir){
     }
 }
 
+.checkBiocDepsDESC <- function(dcf, which = c("Depends", "Imports")) {
+    handleCheck("Checking for Bioconductor software dependencies...")
+    which_fields <- dcf[, colnames(dcf) %in% which]
+    all_deps <- unlist(
+        lapply(which_fields, function(x) strsplit(x, ",\\s*")[[1L]]),
+        use.names = FALSE
+    )
+    all_deps <- gsub("(\\w+)\\s+\\(.*\\)$", "\\1", all_deps)
+    all_deps <- all_deps[all_deps != "R"]
+    repo <- BiocManager:::.repositories_bioc(BiocManager::version())["BioCsoft"]
+    biocdb <- utils::available.packages(repos = repo)
+    bioc_deps <- all_deps %in% rownames(biocdb)
+    percent <- unname(round(prop.table(table(bioc_deps))["TRUE"], 2L) * 100)
+
+    if (!any(bioc_deps)) {
+        views <- .parseBiocViews(dcf)
+        handleFUN <-
+            if ("Infrastructure" %in% views) handleNote else handleWarning
+        msg <- "No Bioconductor dependencies detected. Note that some
+            infrastructure packages may not have Bioconductor dependencies.
+            For more information, reach out to the Bioconductor community
+            and/or consider a CRAN submission."
+        handleFUN(msg)
+    } else {
+        handleMessage(
+            "Bioconductor dependencies found in Imports & Depends (",
+            percent,
+            "%)."
+        )
+    }
+}
+
 checkDescription <- function(package_dir) {
     handleCheck("Checking if DESCRIPTION is well formatted...")
     dcf <- tryCatch({
@@ -2365,13 +2455,8 @@ checkDescription <- function(package_dir) {
         handleError("Do not use Author/Maintainer fields. Use Authors@R.")
 }
 
-checkDESCRIPTIONFile <- function(package_dir) {
-    dcf <- read.dcf(file.path(package_dir, "DESCRIPTION"))
-    .checkLicenseForRestrictiveUse(dcf[,"License"])
-
-    .checkDESCfields(dcf)
-
-    handleCheck("Checking for pinned package versions...")
+.checkPinnedDeps <- function(dcf) {
+    handleCheck("Checking for pinned package versions in DESCRIPTION...")
     deps <- c("Depends", "Imports", "Suggests", "Enhances", "LinkingTo")
     validdeps <- deps[deps %in% colnames(dcf)]
     doubleeq <- grepl("==", dcf[, validdeps], fixed = TRUE)
@@ -2379,13 +2464,42 @@ checkDESCRIPTIONFile <- function(package_dir) {
         handleError("Dependencies in the DESCRIPTION file contain '=='")
 }
 
+checkDESCRIPTIONFile <- function(package_dir) {
+    dcf <- read.dcf(file.path(package_dir, "DESCRIPTION"))
+
+    .checkLicenseForRestrictiveUse(dcf[,"License"])
+    .checkDESCfields(dcf)
+    .checkBiocDepsDESC(dcf)
+    .checkPinnedDeps(dcf)
+}
+
 checkForCitationFile <- function(package_dir) {
     citfile_location <- file.path(package_dir, "inst", "CITATION")
-    if(file.exists(citfile_location)) {
-        handleCheck("Checking that provided CITATION file is correctly formatted...")
-        cit <- tryCatch(
-            readCitationFile(citfile_location),
-            error = function(e)
-                handleNote("CITATION file might be not correctly formatted"))
+    if (file.exists(citfile_location)) {
+        handleCheck(
+            "Checking that provided CITATION file is correctly formatted..."
+        )
+        cit <- try(readCitationFile(citfile_location), silent = TRUE)
+        if (is(cit, "try-error"))
+            handleWarning(
+                "Unable to read CITATION file with 'utils::readCitationFile()'"
+            )
+        else if (is.null(cit$doi))
+            handleWarning(
+                "The 'doi' argument is missing or empty in the CITATION's ",
+                "'bibentry()'. Only include a CITATION file if there is a ",
+                "preprint or publication associated with this Bioconductor ",
+                "package."
+            )
+    } else {
+        handleNote(
+            "(Optional) CITATION file not found. Only include a CITATION ",
+            "file if there is a preprint or publication for this Bioconductor ",
+            "package. Note that Bioconductor packages are not required to ",
+            "have a CITATION file but it is useful both for users and for ",
+            "tracking Bioconductor project-wide metrics. When including a ",
+            "CITATION file, add the publication using the  'doi' argument ",
+            "of 'bibentry()'."
+        )
     }
 }
